==> kafka-tools-6.0.13-ccs-test-sources.jar: org/apache/kafka/trogdor/workload/TimeIntervalTransactionsGeneratorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.trogdor.workload;

import org.apache.kafka.common.utils.MockTime;
import org.junit.Test;

import static org.junit.Assert.assertEquals;

public class TimeIntervalTransactionsGeneratorTest {
    @Test
    public void testCommitsTransactionAfterIntervalPasses() {
        MockTime time = new MockTime();
        TimeIntervalTransactionsGenerator generator = new TimeIntervalTransactionsGenerator(100, time);

        assertEquals(100, generator.transactionIntervalMs());
        assertEquals(TransactionGenerator.TransactionAction.BEGIN_TRANSACTION, generator.nextAction());
        assertEquals(TransactionGenerator.TransactionAction.NO_OP, generator.nextAction());
        time.sleep(50);
        assertEquals(TransactionGenerator.TransactionAction.NO_OP, generator.nextAction());
        time.sleep(49);
        assertEquals(TransactionGenerator.TransactionAction.NO_OP, generator.nextAction());
        time.sleep(1);
        assertEquals(TransactionGenerator.TransactionAction.COMMIT_TRANSACTION, generator.nextAction());
        assertEquals(TransactionGenerator.TransactionAction.BEGIN_TRANSACTION, generator.nextAction());
    }
}

==> kafka-tools-6.2.9-ccs-test-sources.jar: org/apache/kafka/trogdor/workload/TimeIntervalTransactionsGeneratorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.trogdor.workload;

import static org.junit.jupiter.api.Assertions.assertEquals;

import org.apache.kafka.common.utils.MockTime;
import org.junit.jupiter.api.Test;

public class TimeIntervalTransactionsGeneratorTest {
    @Test
    public void testCommitsTransactionAfterIntervalPasses() {
        MockTime time = new MockTime();
        TimeIntervalTransactionsGenerator generator = new TimeIntervalTransactionsGenerator(100, time);

        assertEquals(100, generator.transactionIntervalMs());
        assertEquals(TransactionGenerator.TransactionAction.BEGIN_TRANSACTION, generator.nextAction());
        assertEquals(TransactionGenerator.TransactionAction.NO_OP, generator.nextAction());
        time.sleep(50);
        assertEquals(TransactionGenerator.TransactionAction.NO_OP, generator.nextAction());
        time.sleep(49);
        assertEquals(TransactionGenerator.TransactionAction.NO_OP, generator.nextAction());
        time.sleep(1);
        assertEquals(TransactionGenerator.TransactionAction.COMMIT_TRANSACTION, generator.nextAction());
        assertEquals(TransactionGenerator.TransactionAction.BEGIN_TRANSACTION, generator.nextAction());
    }
}
